********************************************************************************
* Replication file for: 
* "Anxiety and Depression among Medical Doctors in Catalonia, Italy, and the UK during the COVID-19 Pandemic"
* Authors: Climent Quintana-Domeque (corresponding author); Ines Lee; Anwen Zhang; Eugenio Proto; Michele Battisti; Antonia Ho
* This replication file reproduces the main figures and tables
* Last upated: 31 August 2021 
********************************************************************************

/*Stata version*/
version 16.1

/* Directories */
global path "your-path/Replication" //replace with your path
global output "$path/output"

/* Load data */
use "$path/data/HCWS_data", clear

/* Create binary and percentage versions of key variables */

foreach var in depression anxiety no_ppe vulnerable direct_treat got_death {

cap drop `var'_binary
cap drop `var'_pct
g `var'_binary = `var' // original binary variable 
g `var'_pct = `var'*100 // translate variables into percentage terms

}

/*---------------------------------------------------------------
	TABLE 1: Demographic characteristics of respondents 
--------------------------------------------------------------- */
global var = "man woman age_59 age_60"
global coeflabels = `" man "Men" woman "Women" age_59 "Age < 60" age_60 "Age >= 60" live5below "Lives w/ child under 5" live60 "Lives w/ someone over 60" "'

estpost su $var 
matrix N_total = e(sum)'
matrix frac_total = e(mean)'*100

forval i = 1/3 {
foreach p in 0 1 {
estpost su $var if country_code==`i' & second==`p'
matrix N_country`i'_p`p' = e(sum)'
matrix frac_country`i'_p`p' = e(mean)'*100
}
}

matrix tab1 = N_country1_p0, frac_country1_p0, N_country1_p1, frac_country1_p1, N_country2_p0, frac_country2_p0, N_country2_p1, frac_country2_p1, N_country3_p0, frac_country3_p0, N_country3_p0, frac_country3_p1
mat rownames tab1 = "Sex: Man" "Sex: Woman" "Age: Age< 60" "Age: Age>=60" 
mat colnames tab1 = "Catalonia (wave 1)" "(%)" "Catalonia (wave 2)" "(%)" "Italy (wave 1)" "(%)" "Italy (wave 2)" "(%)" "UK (wave 1)" "(%)" "UK (wave 2)" "(%)"

esttab matrix(tab1, fmt(0 2 0 2 0 2 0 2 0 2 0 2 0 2)) using "$output/Table1.csv", replace nomtitle title(Table 1: Demographic characteristics of respondents) modelwidth(8)

/* ----------------------------------------------------------------------------
	FIGURE 1: Prevalence of anxiety and depression symptoms by country over time 
---------------------------------------------------------------------------- */ 
foreach var in anxiety depression {
replace `var' = `var'_pct // translate variables into percentage terms
}

/*** Graph ***/
foreach var in anxiety depression {

if "`var'" == "anxiety" local s = "(A) Anxiety"
if "`var'" == "depression" local s = "(B) Depression"

qui mean `var' if second==0, over(country_code) 
est sto `var'_w1
qui mean `var' if second==1, over(country_code) 
est sto `var'_w2 

coefplot (`var'_w1, recast(bar) barwidth(0.4) fcolor(none) lcolor(black) offset(-0.2)) ///
		 (`var'_w1,  mlabel mlabpos(12) mlabgap(*8) nokey ms(i) pstyle(p1) offset(-0.2) mcolor(black) mlabsize(medium)) ///
		 (`var'_w2, recast(bar) barwidth(0.4) fcolor(*.5) fcolor(gs14) lcolor(black) offset(0.2)) ///
		 (`var'_w2,  mlabel mlabpos(12) mlabgap(*8) nokey ms(i) pstyle(p1) offset(0.2) mcolor(black) mlabsize(medium)), /// 
		 vertical ciopts(recast(rcap) lwidth(thin) lcolor(black)) ///
		 format(%9.1f) plotregion(margin(b=0)) ///
		 ylabel(0(20)40, format(%3.0f) labsize(medium)) yscale(range(0 40)) ///
		 title("`s'") ///
		 coeflabels(c.`var'@1.country_code="Catalonia" c.`var'@2.country_code="Italy" c.`var'@3.country_code="UK" , notick labgap(1) labsize(medium)) ///
		 legend(order (2 "Jun 2020" 6 "Nov/Dec 2020") col(2) size(vsmall) symxsize(*0.25) bmargin(zero) position(6) ring(0) row(1) bplacement(neast) region(lwidth(none) lcolor(none))) ///
		 graphregion(color(white)) 

graph save Graph "$output/`var'_barchart.gph", replace
}

grc1leg "$output/anxiety_barchart.gph" "$output/depression_barchart.gph" , imargin(vsmall) scheme(s1color)  iscale(*0.80) graphregion(margin(vsmall)) legendfrom("$output/depression_barchart.gph") fxsize(70) col(1)

graph export "$output/Fig1.png", as(png) replace 
graph export "$output/Fig1.tif", as(tif) width(2000) replace 

erase "$output/depression_barchart.gph"
erase "$output/anxiety_barchart.gph"

/*-----------------------------------------------------------------------------
	FIGURE 2: Prevalence of anxiety and depression by sex and age across countries
-----------------------------------------------------------------------------*/
foreach var in anxiety depression {
replace `var' = `var'_pct // translate variables into percentage terms
}

/*** Graphs ***/
foreach var in anxiety depression {

if "`var'" == "anxiety" local s = "(A) Anxiety"
if "`var'" == "depression" local s = "(B) Depression"

qui mean `var' if woman==0, over(country_code) 
est sto `var'_man
qui mean `var' if woman==1, over(country_code) 
est sto `var'_woman

coefplot (`var'_man, recast(bar) barwidth(0.4) fcolor(none) lcolor(black) offset(-0.2)) ///
		 (`var'_man,  mlabel mlabpos(12) mlabgap(*10) nokey ms(i) pstyle(p1) offset(-0.2) mcolor(black) mlabsize(medium)) ///
		 (`var'_woman, recast(bar) barwidth(0.4) fcolor(*.5) fcolor(gs14) lcolor(black) offset(0.2)) ///
		 (`var'_woman,  mlabel mlabpos(12) mlabgap(*10) nokey ms(i) pstyle(p1) offset(0.2) mcolor(black)  mlabsize(medium)), /// 
		 vertical ciopts(recast(rcap) lwidth(thin) lcolor(black)) ///
		 format(%9.1f) plotregion(margin(b=0)) ///
		 ylabel(0(20)40, format(%3.0f) labsize(medium)) yscale(range(0 40)) ///
		 title("`s' by sex") ///
		 coeflabels(c.`var'@1.country_code="Catalonia" c.`var'@2.country_code="Italy" c.`var'@3.country_code="UK" , notick labgap(1) labsize(medium)) ///
		 legend(order (2 "Men" 6 "Women") col(2) size(medium) symxsize(*0.25) bmargin(tiny) position(6) ring(0) row(1) bplacement(nw) region(lwidth(none) lcolor(none))) ///
		 graphregion(color(white)) 

graph save Graph "$output/`var'_gender_barchart.gph", replace

}

foreach var in anxiety depression {

if "`var'" == "anxiety" local s = "(C) Anxiety"
if "`var'" == "depression" local s = "(D) Depression"

qui mean `var' if age_60==0, over(country_code) 
est sto `var'_g2
qui mean `var' if age_60==1, over(country_code) 
est sto `var'_g3

coefplot (`var'_g2, recast(bar) barwidth(0.4) fcolor(*.5) fcolor(none) lcolor(black) offset(-0.2)) ///
		 (`var'_g2,  mlabel mlabpos(12) mlabgap(*10) nokey ms(i) pstyle(p1) offset(-0.2) mcolor(black) mlabsize(medium)) ///
		 (`var'_g3, recast(bar) barwidth(0.4) fcolor(*.5) fcolor(gs14) lcolor(black) offset(0.2)) ///
		 (`var'_g3,  mlabel mlabpos(12) mlabgap(*10) nokey ms(i) pstyle(p1) offset(0.2) mcolor(black) mlabsize(medium)), /// 
		 vertical ciopts(recast(rcap) lwidth(thin) lcolor(black)) ///
		 format(%9.1f) plotregion(margin(b=0)) ///
		 ylabel(0(20)40, format(%3.0f) labsize(medium)) yscale(range(0 40)) ///
		 title("`s' by age") ///
		 coeflabels(c.`var'@1.country_code="Catalonia" c.`var'@2.country_code="Italy" c.`var'@3.country_code="UK" , notick labgap(1) labsize(medium)) ///
		 legend(order (2 "Age < 60" 6 "Age >= 60") col(2) size(medium) symxsize(*0.25) bmargin(tiny) position(6) ring(0) row(1) bplacement(nw) region(lwidth(none) lcolor(none))) ///
		 graphregion(color(white)) 

graph save Graph "$output/`var'_age_barchart.gph", replace

}

graph combine "$output/anxiety_gender_barchart.gph" "$output/depression_gender_barchart.gph" "$output/anxiety_age_barchart.gph" "$output/depression_age_barchart.gph" , imargin(vsmall) scheme(s1color) iscale(*0.80) graphregion(margin(vsmall)) col(2) 

graph export "$output/Fig2.png", as(png) replace 
graph export "$output/Fig2.tif", as(tif) width(2000) replace 

foreach var in anxiety depression {
erase "$output/`var'_gender_barchart.gph"
erase "$output/`var'_age_barchart.gph"
}

/*-----------------------------------------------------------------------------
	FIGURE 3: Perceptions of safety and COVID-19 exposure in the workplace
-----------------------------------------------------------------------------*/

foreach var in no_ppe vulnerable direct_treat got_death {
replace `var' = `var'_pct // translate variables into percentage terms
}

foreach var in no_ppe vulnerable direct_treat got_death {

if "`var'" == "no_ppe" local s = "(A) Do not have necessary PPE"
if "`var'" == "vulnerable" local s = "(B) Feel vulnerable and exposed"
if "`var'" == "direct_treat" local s = "(C) Directly treat COVID-19 patient"
if "`var'" == "got_death" local s = "(D) >=1 COVID-19 death at workplace"

qui mean `var' if second==0, over(country_code) 
est sto `var'_w1
qui mean `var' if second==1, over(country_code) 
est sto `var'_w2 

coefplot (`var'_w1, recast(bar) barwidth(0.4) fcolor(none) lcolor(black) offset(-0.2)) ///
		 (`var'_w1,  mlabel mlabpos(12) mlabgap(*5) nokey ms(i) pstyle(p1) offset(-0.2) mcolor(black) mlabsize(medium)) ///
		 (`var'_w2, recast(bar) barwidth(0.4) fcolor(*.5) fcolor(gs14) lcolor(black) offset(0.2)) ///
		 (`var'_w2,  mlabel mlabpos(12) mlabgap(*5) nokey ms(i) pstyle(p1) offset(0.2) mcolor(black) mlabsize(medium)), /// 
		 vertical ciopts(recast(rcap) lwidth(thin) lcolor(black)) ///
		 format(%9.1f) plotregion(margin(b=0)) ///
		 ylabel(0(50)100, format(%3.0f) labsize(medium)) yscale(range(0 100)) ///
		 title("`s'") ///
		 coeflabels(c.`var'@1.country_code="Catalonia" c.`var'@2.country_code="Italy" c.`var'@3.country_code="UK" , notick labgap(1) labsize(medium)) ///
		 legend(order (2 "June 2020" 6 "Nov/Dec 2020") col(2) size(small) symxsize(*0.25) bmargin(zero) position(6) ring(0) row(1) bplacement(neast) region(lwidth(none) lcolor(none))) ///
		 graphregion(color(white)) 

graph save Graph "$output/`var'_barchart.gph", replace
}

grc1leg "$output/no_ppe_barchart.gph" "$output/vulnerable_barchart.gph" "$output/direct_treat_barchart.gph" "$output/got_death_barchart.gph", imargin(vsmall) scheme(s1color) iscale(*0.80) graphregion(margin(vsmall)) legendfrom("$output/no_ppe_barchart.gph") col(2) 

graph export "$output/Fig3.png", as(png) replace 
graph export "$output/Fig3.tif", as(tif) width(2000) replace 

foreach var in no_ppe vulnerable direct_treat got_death {
	erase "$output/`var'_barchart.gph"
}

/*-----------------------------------------------------------------------------
	FIGURE 4: Risk factors of anxiety and depression symptoms, odds ratios and 95 % CI
-----------------------------------------------------------------------------*/

foreach var in depression anxiety no_ppe vulnerable direct_treat got_death {

replace `var' = `var'_binary // translate variables into percentage terms

}

global controls = "woman age_59 second no_ppe vulnerable little_concern covid direct_treat help_covid_related got_death poor_health underlying over_40 smoke vaccine_flu_this live5below live60 i.occupation i.inst_code"

/* Logit models for separate countries */
forval i = 1/3 {
foreach var in depression anxiety {
qui logit `var' $controls if country_code==`i', or

qui su `var'  if country_code==`i'
qui estadd scalar y_mu=r(mean)
est sto `var'_`i'
}
}

/* Logit models for all countries */
foreach var in depression anxiety {
qui logit `var' $controls , or
qui su `var' 
qui estadd scalar y_mu=r(mean)
est sto `var'_4
}

/*** Graph output ***/

global keep = "woman age_59 second no_ppe vulnerable little_concern covid direct_treat help_covid_related got_death poor_health underlying over_40"

global coeflabels = `" woman="Woman" age_59="Age < 60" second="Survey round 2"  no_ppe= `" "Does not have necessary PPE" "' little_concern=`" "Little concern for safety" "'  vulnerable= `" "Feel vulnerable/exposed" "'  covid = `" "Had COVID-19 symptoms" "'  direct_treat =`" "Directly treat COVID-19 patients" "' help_covid_related =`" "Help w/ COVID-19 related tasks" "'  got_death= `" ">=1 COVID-19 death in workplace" "' poor_health="Normal/Below-normal health" underlying =`" "Underlying health condition" "' over_40 = `" "Worked >= 40 hours" "'  "' 

coefplot (anxiety_4, offset(0.2) msymbol(C)  mlabposition(2)) (depression_4, offset(-0.2) msymbol(D) mlabposition(2)) ,  eform keep($keep) coeflabels($coeflabels , noticks labsize(small)) groups(woman age_59 second =`" "{bf:Sex / Age /}" "{bf: Survey wave}" "'  no_ppe vulnerable little_concern =`" "{bf:Workplace}" "{bf:safety}" "' covid direct_treat help_covid_related got_death  =`" "{bf:COVID-19}" "{bf:Experience}" "' poor_health underlying over_40=`" "{bf:Health}" "{bf:& Lifestyle}" "', nogap labsize(small) glstyle(foreground) ) xline(1, lpattern(dash) lcolor(gs12) lwidth(thin)) mlabsize(vsmall) mlabgap(*0.5) mfcolor(white) xscale(range(0.5 4)) xlabel(0.5(0.5)4,format(%2.1f) labsize(vsmall)) mlabel(cond(@pval<.001, string(@b,"%9.2f")+"***", cond(@pval<.01, string(@b,"%9.3f")+"**", cond(@pval<.05, string(@b,"%9.2f")+"*", string(@b,"%9.2f"))))) legend(order(2 "Anxiety" 4 "Depression") row(2) bplacement(neast) position(6) ring(0)  symxsize(*0.5) size(small) region(lwidth(none)) bmargin(zero)) graphregion(color(white) margin(small)) 

graph export "$output/Fig4.png", as(png) replace 
graph export "$output/Fig4.tif", as(tif) width(2000) replace 

/*** Table output (TABLE S7: Logit odds-ratios and 95% confidence intervals) ***/

global stats = `" y_mu N ,fmt(%6.2f %18.0f) labels("Dep var mean" "Observations") "'

global keep = "woman age_59 second no_ppe vulnerable little_concern covid direct_treat help_covid_related got_death poor_health underlying over_40 smoke vaccine_flu_this live5below live60"

global coeflabels =  `" woman "Woman" age_59 "Age<60" second "Survey round 2" no_ppe "No necessary PPE" vulnerable "Feel vulnerable/exposed" little_concern "Little concern for safety" covid "Had COVID-19 symptoms" direct_treat "Directly treat COVID-19 patients" help_covid_related "Help w/ COVID-19 related tasks" got_death ">=1 COVID-19 death in workplace" poor_health "Normal/below-normal health" underlying "Underlying health condition" over_40 "Worked >= 40 hours" smoke "Smokes" vaccine_flu_this "Had flu vaccine this season" live5below "Lives w/ child u5" live60 "Lives w/ someone over 60" "' 

global refcat = `" woman "Demographics" no_PPE "Perceptions of workplace safety" covid "Exposure to covid" poor_health "Health status and behaviours" live5below "Household composition" , nolabel "'

esttab anxiety_4 depression_4 anxiety_1 depression_1 anxiety_2 depression_2 anxiety_3 depression_3  using "$output/TableS7.csv", replace eform keep($keep) coeflabels(${coeflabels}) mtitles("Anxiety" "Depression" "Anxiety" "Depression" "Anxiety" "Depression" "Anxiety" "Depression" ) mgroups("All" "Catalonia" "Italy" "UK" , pattern(1 0 1 0 1 0 1 0)) b(%6.2f) ci(%6.2f) stats(${stats}) collabels(none) title(Logit odds-ratios and 95% confidence intervals) refcat($refcat) addnotes("All models include occupational fixed effects and institutional fixed effects. * p<0.05 ** p<0.01 *** p<0.001.") nonotes plain brackets nogaps star(* 0.05 ** 0.01 *** 0.001)

********************************************************************************
**END**
********************************************************************************
